==> haskell-linear-base-0.4.0-21-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-linear-base.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 linear-base
version:              0.4.0
visibility:           public
id:                   linear-base-0.4.0-HmGjKB8z8Sp6Q7ku0tNnJb
key:                  linear-base-0.4.0-HmGjKB8z8Sp6Q7ku0tNnJb
license:              MIT
copyright:            (c) Tweag Holding and affiliates
maintainer:           arnaud.spiwack@tweag.io
author:               Tweag
homepage:             https://github.com/tweag/linear-base#README
synopsis:             Standard library for linear types.
description:          Please see README.md.
category:             Prelude
abi:                  c200009e69f5925be2bc8863053f3b73
exposed:              True
exposed-modules:
    Control.Functor.Linear Control.Functor.Linear.Internal.Class
    Control.Functor.Linear.Internal.Instances
    Control.Functor.Linear.Internal.Kan
    Control.Functor.Linear.Internal.MonadTrans
    Control.Functor.Linear.Internal.Reader
    Control.Functor.Linear.Internal.State Control.Monad.IO.Class.Linear
    Control.Optics.Linear Control.Optics.Linear.Internal
    Control.Optics.Linear.Iso Control.Optics.Linear.Lens
    Control.Optics.Linear.Prism Control.Optics.Linear.Traversal
    Data.Arity.Linear Data.Arity.Linear.Internal Data.Array.Destination
    Data.Array.Destination.Internal Data.Array.Mutable.Linear
    Data.Array.Mutable.Linear.Internal
    Data.Array.Mutable.Unlifted.Linear Data.Array.Polarized
    Data.Array.Polarized.Pull Data.Array.Polarized.Pull.Internal
    Data.Array.Polarized.Push Data.Bifunctor.Linear
    Data.Bifunctor.Linear.Internal.Bifunctor
    Data.Bifunctor.Linear.Internal.SymmetricMonoidal Data.Bool.Linear
    Data.Either.Linear Data.Functor.Linear
    Data.Functor.Linear.Internal.Applicative
    Data.Functor.Linear.Internal.Functor
    Data.Functor.Linear.Internal.Traversable
    Data.HashMap.Mutable.Linear Data.HashMap.Mutable.Linear.Internal
    Data.List.Linear Data.Maybe.Linear Data.Monoid.Linear
    Data.Monoid.Linear.Internal.Monoid
    Data.Monoid.Linear.Internal.Semigroup Data.Num.Linear
    Data.Ord.Linear Data.Ord.Linear.Internal.Eq
    Data.Ord.Linear.Internal.Ord Data.Profunctor.Kleisli.Linear
    Data.Profunctor.Linear Data.Replicator.Linear
    Data.Replicator.Linear.Internal
    Data.Replicator.Linear.Internal.Instances
    Data.Replicator.Linear.Internal.ReplicationStream
    Data.Set.Mutable.Linear Data.Set.Mutable.Linear.Internal
    Data.Tuple.Linear Data.Tuple.Linear.Compat Data.Unrestricted.Linear
    Data.Unrestricted.Linear.Internal.Consumable
    Data.Unrestricted.Linear.Internal.Dupable
    Data.Unrestricted.Linear.Internal.Instances
    Data.Unrestricted.Linear.Internal.Movable
    Data.Unrestricted.Linear.Internal.Ur
    Data.Unrestricted.Linear.Internal.UrT Data.V.Linear
    Data.V.Linear.Internal Data.V.Linear.Internal.Instances
    Data.Vector.Mutable.Linear Data.Vector.Mutable.Linear.Internal
    Debug.Trace.Linear Foreign.Marshal.Pure
    Foreign.Marshal.Pure.Internal Prelude.Linear
    Prelude.Linear.GenericUtil Prelude.Linear.Generically
    Prelude.Linear.Internal Prelude.Linear.Internal.Generically
    Prelude.Linear.Internal.TypeEq Prelude.Linear.Unsatisfiable
    Streaming.Linear Streaming.Linear.Internal.Consume
    Streaming.Linear.Internal.Interop Streaming.Linear.Internal.Many
    Streaming.Linear.Internal.Process Streaming.Linear.Internal.Produce
    Streaming.Linear.Internal.Type Streaming.Prelude.Linear
    System.IO.Linear System.IO.Resource.Linear
    System.IO.Resource.Linear.Internal Unsafe.Linear

import-dirs:          /usr/lib/ghc-9.4.8/site-local/linear-base-0.4.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/linear-base-0.4.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/linear-base-0.4.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-linear-base
hs-libraries:         HSlinear-base-0.4.0-HmGjKB8z8Sp6Q7ku0tNnJb
depends:
    base-4.17.2.1 containers-0.6.7 ghc-prim-0.9.1
    hashable-1.4.4.0-E3AlBtIk95ULiiCgr6U6fg
    linear-generics-0.2.3-E2awSe7g81ECfOO8QNUe9m
    primitive-0.9.1.0-GChnkqMWBe7B15Z0K3IGlf
    storable-tuple-0.1-EL7betwlePLH30t6qx43IZ text-2.0.2
    transformers-0.5.6.2 vector-0.13.2.0-cop25r7TnE5vewvd3oOyK

haddock-interfaces:   /usr/share/doc/haskell-linear-base/html/linear-base.haddock
haddock-html:         /usr/share/doc/haskell-linear-base/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-linear-base-0.5.0-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-linear-base.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 linear-base
version:              0.5.0
visibility:           public
id:                   linear-base-0.5.0-8tpMOditDce9tMwaXVzRDr
key:                  linear-base-0.5.0-8tpMOditDce9tMwaXVzRDr
license:              MIT
copyright:            (c) Tweag Holding and affiliates
maintainer:           arnaud.spiwack@tweag.io
author:               Tweag
homepage:             https://github.com/tweag/linear-base#README
synopsis:             Standard library for linear types.
description:          Please see README.md.
category:             Prelude
abi:                  45f803cbfae4c5e1ba3c110b47a4a69a
exposed:              True
exposed-modules:
    Control.Functor.Linear Control.Functor.Linear.Internal.Class
    Control.Functor.Linear.Internal.Instances
    Control.Functor.Linear.Internal.Kan
    Control.Functor.Linear.Internal.MonadTrans
    Control.Functor.Linear.Internal.Reader
    Control.Functor.Linear.Internal.State Control.Monad.IO.Class.Linear
    Control.Optics.Linear Control.Optics.Linear.Internal
    Control.Optics.Linear.Iso Control.Optics.Linear.Lens
    Control.Optics.Linear.Prism Control.Optics.Linear.Traversal
    Data.Arity.Linear Data.Arity.Linear.Internal Data.Array.Destination
    Data.Array.Destination.Internal Data.Array.Mutable.Linear
    Data.Array.Mutable.Linear.Internal
    Data.Array.Mutable.Unlifted.Linear Data.Array.Polarized
    Data.Array.Polarized.Pull Data.Array.Polarized.Pull.Internal
    Data.Array.Polarized.Push Data.Bifunctor.Linear
    Data.Bifunctor.Linear.Internal.Bifunctor
    Data.Bifunctor.Linear.Internal.SymmetricMonoidal Data.Bool.Linear
    Data.Either.Linear Data.Functor.Linear
    Data.Functor.Linear.Internal.Applicative
    Data.Functor.Linear.Internal.Functor
    Data.Functor.Linear.Internal.Traversable
    Data.HashMap.Mutable.Linear Data.HashMap.Mutable.Linear.Internal
    Data.List.Linear Data.Maybe.Linear Data.Monoid.Linear
    Data.Monoid.Linear.Internal.Monoid
    Data.Monoid.Linear.Internal.Semigroup Data.Num.Linear
    Data.Ord.Linear Data.Ord.Linear.Internal.Eq
    Data.Ord.Linear.Internal.Ord Data.Profunctor.Kleisli.Linear
    Data.Profunctor.Linear Data.Replicator.Linear
    Data.Replicator.Linear.Internal
    Data.Replicator.Linear.Internal.Instances
    Data.Replicator.Linear.Internal.ReplicationStream
    Data.Set.Mutable.Linear Data.Set.Mutable.Linear.Internal
    Data.Tuple.Linear Data.Tuple.Linear.Compat Data.Unrestricted.Linear
    Data.Unrestricted.Linear.Internal.Consumable
    Data.Unrestricted.Linear.Internal.Dupable
    Data.Unrestricted.Linear.Internal.Instances
    Data.Unrestricted.Linear.Internal.Movable
    Data.Unrestricted.Linear.Internal.Ur
    Data.Unrestricted.Linear.Internal.UrT Data.V.Linear
    Data.V.Linear.Internal Data.V.Linear.Internal.Instances
    Data.Vector.Mutable.Linear Data.Vector.Mutable.Linear.Internal
    Debug.Trace.Linear Foreign.Marshal.Pure
    Foreign.Marshal.Pure.Internal Prelude.Linear
    Prelude.Linear.GenericUtil Prelude.Linear.Generically
    Prelude.Linear.Internal Prelude.Linear.Internal.Generically
    Prelude.Linear.Internal.TypeEq Prelude.Linear.Unsatisfiable
    Streaming.Linear Streaming.Linear.Internal.Consume
    Streaming.Linear.Internal.Interop Streaming.Linear.Internal.Many
    Streaming.Linear.Internal.Process Streaming.Linear.Internal.Produce
    Streaming.Linear.Internal.Type Streaming.Prelude.Linear
    System.IO.Linear System.IO.Resource.Linear
    System.IO.Resource.Linear.Internal Unsafe.Linear

import-dirs:          /usr/lib/ghc-9.4.8/site-local/linear-base-0.5.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/linear-base-0.5.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/linear-base-0.5.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-linear-base
hs-libraries:         HSlinear-base-0.5.0-8tpMOditDce9tMwaXVzRDr
depends:
    base-4.17.2.1 containers-0.6.7 ghc-bignum-1.3 ghc-prim-0.9.1
    hashable-1.4.4.0-E3AlBtIk95ULiiCgr6U6fg
    linear-generics-0.2.3-E2awSe7g81ECfOO8QNUe9m
    primitive-0.9.1.0-GChnkqMWBe7B15Z0K3IGlf
    storable-tuple-0.1-EL7betwlePLH30t6qx43IZ text-2.0.2
    transformers-0.5.6.2 vector-0.13.2.0-cop25r7TnE5vewvd3oOyK

haddock-interfaces:   /usr/share/doc/haskell-linear-base/html/linear-base.haddock
haddock-html:         /usr/share/doc/haskell-linear-base/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 z-linear-base-z-examples
version:              0.5.0
package-name:         linear-base
lib-name:             examples
id:                   linear-base-0.5.0-4KM5yD6Nm5iDegKvvrL5xW-examples
key:                  linear-base-0.5.0-4KM5yD6Nm5iDegKvvrL5xW-examples
license:              MIT
copyright:            (c) Tweag Holding and affiliates
maintainer:           arnaud.spiwack@tweag.io
author:               Tweag
homepage:             https://github.com/tweag/linear-base#README
synopsis:             Standard library for linear types.
description:          Please see README.md.
category:             Prelude
abi:                  ebbe7b9883045121656ef9f9b5f7a08c
exposed-modules:
    Foreign.Heap Foreign.List Simple.FileIO Simple.Pure
    Simple.Quicksort Simple.TopSort

import-dirs:          /usr/lib/ghc-9.4.8/site-local/linear-base-0.5.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/linear-base-0.5.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/linear-base-0.5.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-linear-base
hs-libraries:         HSlinear-base-0.5.0-4KM5yD6Nm5iDegKvvrL5xW-examples
depends:
    base-4.17.2.1 linear-base-0.5.0-8tpMOditDce9tMwaXVzRDr
    storable-tuple-0.1-EL7betwlePLH30t6qx43IZ text-2.0.2
    vector-0.13.2.0-cop25r7TnE5vewvd3oOyK

haddock-interfaces:   /usr/share/doc/haskell-linear-base/html/linear-base.haddock
haddock-html:         /usr/share/doc/haskell-linear-base/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
